# cs207-FinalProject
## Group Name: 19.
## Group members: 
### Yichen Geng
### Yingsi Jian
### Matthieu Meeus
### Lihong Zhang
               
[![Build Status](https://travis-ci.org/BackPropagators/cs207-FinalProject.svg?branch=master)](https://travis-ci.org/BackPropagators/cs207-FinalProject)

[![Coverage Status](https://codecov.io/gh/BackPropagators/cs207-FinalProject/branch/master/graph/badge.svg)](https://codecov.io/gh/BackPropagators/cs207-FinalProject)


